#!/bin/sh
product=mpgedit_0.7
install_root=/usr/local

man1="mpgedit.1 xmpgedit.1 decoder.so.1 mp3decoder.sh.1
      scramble_times.pl.1 scramble.pl.1 unscramble.pl.1"
lib="libdecoder_mpg123.so libdecoder_popen.so libmpglib_mpgedit.so"
bin="mpgedit mpgedit_nocurses mp3decoder.sh"
guibin="xmpgedit"
share="eject.xpm pause.xpm record.xpm next_t.xpm play.xpm stop.xpm"


# Attempt "college best" to install pixmap_path in gtkrc file
#
do_gtkrc_config()
{
  if [ ! -d "/usr/local/etc/gtk-2.0" ]; then
    if [ "`uname`" = "Linux" ]; then
      count=`locate etc/gtk-2.0 | grep 'gtk-2.0$' | wc -l`
      if [ $count -gt 1 ]; then
        echo "WARNING: Unable to determine GTK+ 2.0 install directory"
        echo "         You must manually configure the gtkrc file pixmap_path"
        return
      fi
      gtkrc="`locate etc/gtk-2.0 | grep 'gtk-2.0$'`/gtkrc"
    fi
  else
    gtkrc="/usr/local/etc/gtk-2.0"
  fi
  if [ -f "$gtkrc/gtkrc" ]; then
    tmptst=`grep pixmap_path "$gtkrc/gtkrc"`
    if [ -z "$tmptst" ]; then
      # This is simple, add pixmap_path to existing gtkrc file
      #
      echo "pixmap_path \"$install_root/share/xmpgedit\"" >> "$gtkrc"
    else
      # Determine if xmpgedit is already in pixmap path
      #
      tmptst=`grep "$install_root/share/xmpgedit" "$gtkrc/gtkrc"`
      if [ -z "$tmptst" ]; then
        sed -e "s|pixmap_path \(.*\)\"|pixmap_path \1:$install_root/share/xmpgedit\"|" "$gtkrc/gtkrc" > /tmp/gtkrc$$
        i=1
        while [ -f "$gtkrc/gtkrc.$i" ]; do
          i=`expr $i + 1`
        done
        cp "$gtkrc/gtkrc" "$gtkrc/gtkrc.$i"
        cp "/tmp/gtkrc$$" "$gtkrc/gtkrc"
      fi
    fi
  else
    # This is simple, create gtkrc with needed entry
    #
    echo "pixmap_path \"$install_root/share/xmpgedit\"" > "$gtkrc/gtkrc"
  fi

  unset count tmptst gtkrc i
}


do_install()
{
  get_install_root
  
  echo "Installing '$product' in '$install_root'"
  install -d $install_root/man/man1
  install -d $install_root/lib
  install -d $install_root/bin
  
  echo "Installing man pages ($install_root/man/man1)..."
  install -m 444 $man1 $install_root/man/man1
  
  echo "Installing shared libraries ($install_root/lib)..."
  install $lib $install_root/lib
  
  echo "Installing executables ($install_root/bin)..."
  install $bin $install_root/bin

  if [ -d "gui" ]; then
    cd gui
  fi
  echo "Installing GUI executables ($install_root/bin)..."
  install $guibin $install_root/bin

  echo "Installing xmpgedit pixmaps ($install_root/share/xmpgedit)..."
  #
  # Note: trailing slash here is extremely important, as it tells -D
  # xmpgedit is a directory, not a file.
  #
  install -d        $install_root/share/xmpgedit/
  install -D $share $install_root/share/xmpgedit/
  if [ -d "gui" ]; then
    cd ..
  fi
  
  rm -f $install_root/lib/libmpgedit_decoder.so
  ln -s $install_root/lib/libdecoder_mpg123.so \
        $install_root/lib/libmpgedit_decoder.so
  
  line=`grep $install_root/lib /etc/ld.so.conf`
  if [ -z "$line" ]; then
    echo
    echo "$install_root/lib not found in /etc/ld.co.conf"
    echo "This is needed for proper operation of mpgedit"
    echo
    echo -n "  Do you want to add this now? [Y/n] "
    read line
    line=`echo $line | tr '[A-Z]' '[a-z]'`
    if [ "$line" != "n" -a "$line" != "no" ]; then
      echo "$install_root/lib" >> /etc/ld.so.conf
      /sbin/ldconfig
    fi
  fi

  do_gtkrc_config

  echo "Finished installing '$product'"
  echo
  echo "Remember to add '$install_root/bin' to your PATH environment variable"
  echo "Remember to add '$install_root/man/man1' to your MANPATH environment variable"
}


do_uninstall()
{
  get_install_root "un"
  if [ ! -d "$install_root" ]; then
    echo "ERROR: uninstall directory does not exist"
    exit 1
  fi

  echo "Uninstalling '$product' in '$install_root'"
  for i in $man1; do
    if [ -f $install_root/man/man1/$i ]; then
      echo "rm -f $install_root/man/man1/$i"
            rm -f $install_root/man/man1/$i
    fi
  done
  for i in $lib; do
    if [ -f $install_root/lib/$i ]; then
      echo "rm -f $install_root/lib/$i"
            rm -f $install_root/lib/$i
    fi
  done
  for i in $bin $guibin; do
    if [ -f $install_root/bin/$i ]; then
     echo "rm -f $install_root/bin/$i"
           rm -f $install_root/bin/$i
    fi
  done
  if [ -d $install_root/share/xmpgedit ]; then
    for i in $share; do
      if [ -f $install_root/share/xmpgedit/$i ]; then
       echo "rm -f $install_root/share/xmpgedit/$i"
             rm -f $install_root/share/xmpgedit/$i
      fi
    done
    rmdir $install_root/share/xmpgedit/
  fi
  if [ -h $install_root/lib/libmpgedit_decoder.so ]; then
    echo "rm -f $install_root/lib/libmpgedit_decoder.so"
          rm -f $install_root/lib/libmpgedit_decoder.so
  fi
  echo "Finished uninstalling '$product' in '$install_root'"
}


get_install_root()
{
  prefix=$1
  echo "Current ${prefix}install location is '$install_root'"
  echo -n "  Change location? [y/N] "
  read line
  line=`echo $line | tr '[A-Z]' '[a-z]'`
  if [ "$line" = "y" -o "$line" = "yes" ]; then
    ok=no
    echo
    while [ "$ok" = "no" ]; do
      echo "Enter ${prefix}install directory"
      read new_install_root
      echo "New ${prefix}install directory: '$new_install_root'"
      echo -n "  Is this correct? "
      read line
      line=`echo $line | tr '[A-Z]' '[a-z]'`
      if [ "$line" = "y" -o "$line" = "yes" ]; then
        ok="yes"
      fi
    done
    install_root=$new_install_root
  fi
}

#
# ============================ main =======================
#
uid=`id | sed -e 's/uid=\([0-9][0-9]*\).*/\1/'`
if [ $uid != 0 ]; then
  echo "ERROR: Can only install '$product' as root"
  exit 1;
fi

if [ -z "$1" ]; then
  do_install
  exit 0
elif [ -n "$1" ]; then
  t=`echo "x$1" | grep '^x-u$'`
  if [ -n "$t" ]; then
    do_uninstall
    un="un"
    exit 0
  else
    echo "unrecognized option '$1'"
  fi
fi
